@@ -102,7 +102,7 @@ int checkForAlarm(long alarmTime) {
 
 int handleAlarm(int alarmIndex) {
 
-	char soundFile[200];
+	char *soundFile = NULL;
 	
 	int fadeTime = 60000;		//time to fade alarm in... this will be set by a preference later...
 	
@@ -136,7 +136,7 @@ int handleAlarm(int alarmIndex) {
 				setTabletSystemVolume(0);
 			}
 			
-			sprintf(soundFile, "%s%s", MEDIAPATH, "test.mp3");
+			//sprintf(soundFile, "%s%s", MEDIAPATH, "test.mp3");
 			myAlarmSound = createPlayer("mp3");
 			loadFile(userPreferences.userAlarms[runningAlarmIndex]->sound, myAlarmSound->pipeline);
 			setLoopMode(userPreferences.userAlarms[runningAlarmIndex]->loopSound, myAlarmSound);
@@ -181,6 +181,64 @@ int handleAlarm(int alarmIndex) {
 					ossoDeviceScreenOn();
 				}
 			}
+			break;
+		case ALARMALERTMODESOUNDFOLDER:
+			//Try it crudely here..
+			if (isTablet) {
+				setTabletSystemVolume(0);
+			}
+			
+			//sprintf(soundFile, "%s%s", MEDIAPATH, "test.mp3");
+			
+			if (soundFileIndex == -5) {
+				//need to set it either to 0 or -1 for random
+				if (userPreferences.userAlarms[runningAlarmIndex]->loopSound == 0) {
+					//0 means linear order
+					soundFileIndex = 0;
+				} else if (userPreferences.userAlarms[runningAlarmIndex]->loopSound == 1) {
+					soundFileIndex = -1;
+				}
+			}
+			
+			soundFile = getIndexedMP3FromPath(userPreferences.userAlarms[runningAlarmIndex]->sound, soundFileIndex);
+			
+			myAlarmSound = createPlayer("mp3");
+			if (soundFileIndex > -1) {
+				soundFileIndex++;
+			}
+			
+			if (soundFile != NULL ) {
+				//Now we have to grab the first sound file in the folder
+				
+				loadFile(soundFile, myAlarmSound->pipeline);
+				
+				setLoopMode(2, myAlarmSound);
+				
+				fadeSoundIn(myAlarmSound, fadeTime, userPreferences.maxAlarmVol);
+				//playPipe(myAlarmSound->pipeline);
+				
+				//setPipeVolume(myAlarmSound->pipeline, 40);
+				
+				//printf("Volume is %i\n", getPipeVolume(myAlarmSound->pipeline));
+	
+				//Wake device if it's a tablet
+				if (isTablet) {
+					if (userPreferences.insomniacModeOn == 1 && insomniacMode == 2) {
+						if (isInsomniacDimmed == 1) {
+							//currently we're dimmed, so gradually fade in
+							startWakeFromInsomiaStepped(fadeTime, 30);
+						
+						
+						}
+					} else {			
+						//No Insomniac mode, so turn screen on
+						ossoDeviceScreenOn();
+					}
+				}
+				free(soundFile);
+			}
+			
+					
 			break;
 
 	}
@@ -217,9 +275,12 @@ void stopAlarm() {
 		return; //Fail
 	}
 	
+	//Reset the global soundFileIndex since we're not using it anymore
+	soundFileIndex = -5;
+	
 	switch (userPreferences.userAlarms[runningAlarmIndex]->alertMode) {
 		case 0:	//Play sound
-			
+		case 2:	//Play playlist	
 			cleanupPlayer(myAlarmSound);	
 			if (isTablet) {
 				//Restore original sysVol 
@@ -276,12 +337,13 @@ void stopAlarm() {
 ****************************************************************************/
 
 void snoozeAlarm() {
-	int oldAlarm;
+	int oldAlarm, oldSoundIndex;
 	int currentTime, nextTime;
 	
 	oldAlarm = runningAlarmIndex;
 	
-
+	//Store this for later
+	oldSoundIndex = soundFileIndex;
 
 	//Quick error checking
 	if (runningAlarmIndex < 0 || runningAlarmIndex > userPreferences.userAlarmsCount) {
@@ -304,6 +366,9 @@ void snoozeAlarm() {
 	//Stop the current alarm
 	stopAlarm();
 	
+	//reset sound file index to old value
+	soundFileIndex = oldSoundIndex;
+	
 	//Warn user that we're snoozing somehow...
 	
 	//Go back to insomniac mode if needed
@@ -374,7 +439,7 @@ void getNextAlarmTime() {
 			todayStart = mktime(&todayTest);
 					
 			//Okay we've got the base point, now we need to add teh digit values to get the time
-			if (hours < 13 && userPreferences.userAlarms[i]->ampm == 1) {
+			if (hours < 12 && userPreferences.userAlarms[i]->ampm == 1) {
 				hours += 12;	//Add 12 hours to the time
 			}
 			if (hours == 12 && userPreferences.userAlarms[i]->ampm == 0) {
@@ -458,7 +523,7 @@ void digitUpHH1() {
 	
 	if (changed == 1) {
 		//Redraw the new value
-		animateAlarmScrollerDigit(screen, 0, currHH1 +1, currHH1, 10);
+		animateAlarmScrollerDigit(screen, 0, currHH1 +1, currHH1, 10, &currentTheme.alarmDigitPos[0]);
 		
 		//Save the new time
 		bzero(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM, sizeof(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM));
@@ -492,7 +557,7 @@ void digitUpHH2() {
 	
 	if (changed == 1) {
 		//Redraw the new value
-		animateAlarmScrollerDigit(screen, 1, currHH1 +1, currHH1, 10);
+		animateAlarmScrollerDigit(screen, 1, currHH1 +1, currHH1, 10, &currentTheme.alarmDigitPos[1]);
 		
 		//Save the new time
 		bzero(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM, sizeof(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM));
@@ -524,7 +589,7 @@ void digitUpMM1() {
 	
 	if (changed == 1) {
 		//Redraw the new value
-		animateAlarmScrollerDigit(screen, 2, currHH1 + 1, currHH1, 10);
+		animateAlarmScrollerDigit(screen, 2, currHH1 + 1, currHH1, 10, &currentTheme.alarmDigitPos[2]);
 		
 		//Save the new time
 		bzero(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM, sizeof(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM));
@@ -553,7 +618,7 @@ void digitUpMM2() {
 	
 	if (changed == 1) {
 		//Redraw the new value
-		animateAlarmScrollerDigit(screen, 3, currHH1 + 1, currHH1, 10);
+		animateAlarmScrollerDigit(screen, 3, currHH1 + 1, currHH1, 10, &currentTheme.alarmDigitPos[3]);
 		
 		//Save the new time
 		bzero(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM, sizeof(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM));
@@ -584,7 +649,7 @@ void digitDownHH1() {
 		
 			if (currHH2 > 2) {
 				//Roll to two instead
-				animateAlarmScrollerDigit(screen, 1, currHH2, 2, (currHH2 - 2) * 10);
+				animateAlarmScrollerDigit(screen, 1, currHH2, 2, (currHH2 - 2) * 10, &currentTheme.alarmDigitPos[1]);
 				currHH2 = 2;
 			}
 		
@@ -616,7 +681,7 @@ void digitDownHH1() {
 
 	if (changed == 1) {
 		//Redraw the new value
-		animateAlarmScrollerDigit(screen, 0, currHH1 - 1, currHH1, 10);
+		animateAlarmScrollerDigit(screen, 0, currHH1 - 1, currHH1, 10, &currentTheme.alarmDigitPos[0]);
 		
 		//Save the new time
 		bzero(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM, sizeof(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM));
@@ -697,7 +762,7 @@ void digitDownHH2() {
 
 	if (changed == 1) {
 		//Redraw the new value
-		animateAlarmScrollerDigit(screen, 1, currHH1 - 1, currHH1, 10);
+		animateAlarmScrollerDigit(screen, 1, currHH1 - 1, currHH1, 10, &currentTheme.alarmDigitPos[1]);
 		
 		//Save the new time
 		bzero(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM, sizeof(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM));
@@ -728,7 +793,7 @@ void digitDownMM1() {
 	
 	if (changed == 1) {
 		//Redraw the new value
-		animateAlarmScrollerDigit(screen, 2, currHH1 - 1, currHH1, 10);
+		animateAlarmScrollerDigit(screen, 2, currHH1 - 1, currHH1, 10, &currentTheme.alarmDigitPos[2]);
 		
 		//Save the new time
 		bzero(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM, sizeof(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM));
@@ -758,7 +823,7 @@ void digitDownMM2() {
 	
 	if (changed == 1) {
 		//Redraw the new value
-		animateAlarmScrollerDigit(screen, 3, currHH1 - 1, currHH1, 10);
+		animateAlarmScrollerDigit(screen, 3, currHH1 - 1, currHH1, 10, &currentTheme.alarmDigitPos[3]);
 		
 		//Save the new time
 		bzero(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM, sizeof(userPreferences.userAlarms[currentAlarmNum]->alarmHHMM));
@@ -788,9 +853,9 @@ void drawAlarmDigits(SDL_Surface *screenBuff, char *alarmHHMM) {
 		for (i=0; i< 4; i++) {
 			bzero(thisDigit, sizeof(thisDigit));
 			sprintf(thisDigit, "%c", alarmHHMM[i]);
-		
+			printf("agggggggg\n");
 			//Loop over each digit in the time and draw it accordingly
-			drawAlarmScrollerDigit(screenBuff, i, atoi(thisDigit));
+			drawAlarmScrollerDigit(screenBuff, i, atoi(thisDigit), &currentTheme.alarmDigitPos[i]);
 		
 		
 		}
@@ -807,7 +872,7 @@ void drawAlarmDigits(SDL_Surface *screenBuff, char *alarmHHMM) {
 * Draw the given alarm time time on the alarm digit scrollers
 ****************************************************************************/
 
-void drawAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int digitValue) {
+void drawAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int digitValue, SDL_Rect *digitPosRect) {
 	
 	SDL_Rect sourceRect, targetRect;
 	int digitIndexRef;
@@ -837,18 +902,25 @@ void drawAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int digitVa
 
 	//And off we go!
 
-	targetRect.x = currentTheme.alarmDigitPos[digitIndexRef].x;
-	targetRect.y = currentTheme.alarmDigitPos[digitIndexRef].y;
+	//targetRect.x = currentTheme.alarmDigitPos[digitIndexRef].x;
+	//targetRect.y = currentTheme.alarmDigitPos[digitIndexRef].y;
+	targetRect.x = digitPosRect->x;
+	targetRect.y = digitPosRect->y;
+	
 	targetRect.w = elements[ALARMDIGITSCROLLER]->w;
 	targetRect.h = elements[ALARMDIGITMASK]->h;
 	
 	SDL_FillRect(screenBuff, &targetRect, moodColour);
 	
-	SDL_BlitSurface(elements[ALARMDIGITSCROLLER], &sourceRect, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
+	//SDL_BlitSurface(elements[ALARMDIGITSCROLLER], &sourceRect, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
+	SDL_BlitSurface(elements[ALARMDIGITSCROLLER], &sourceRect, screenBuff, digitPosRect);
+	
 	
 	//Draw the mask
-	SDL_BlitSurface(elements[ALARMDIGITMASK], NULL, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
-	
+	if (elements[ALARMDIGITMASK] != NULL) {
+		//SDL_BlitSurface(elements[ALARMDIGITMASK], NULL, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
+		SDL_BlitSurface(elements[ALARMDIGITMASK], NULL, screenBuff, digitPosRect);
+	}
 
 }
 
@@ -876,9 +948,9 @@ void animateAlarmDigits(SDL_Surface *screenBuff, char *oldAlarmHHMM, char *newAl
 		
 			//Loop over each digit in the time and draw it accordingly
 			if (atoi(thisOldDigit) - atoi(thisNewDigit) > 0) {
-				animateAlarmScrollerDigit(screenBuff, i, atoi(thisOldDigit), atoi(thisNewDigit), (atoi(thisOldDigit) - atoi(thisNewDigit)) * 10);
+				animateAlarmScrollerDigit(screenBuff, i, atoi(thisOldDigit), atoi(thisNewDigit), (atoi(thisOldDigit) - atoi(thisNewDigit)) * 10, &currentTheme.alarmDigitPos[i]);
 			} else if (atoi(thisOldDigit) - atoi(thisNewDigit) < 0) {
-				animateAlarmScrollerDigit(screenBuff, i, atoi(thisOldDigit), atoi(thisNewDigit), (atoi(thisNewDigit) - atoi(thisOldDigit)) * 10);
+				animateAlarmScrollerDigit(screenBuff, i, atoi(thisOldDigit), atoi(thisNewDigit), (atoi(thisNewDigit) - atoi(thisOldDigit)) * 10, &currentTheme.alarmDigitPos[i]);
 			}
 			//drawAlarmScrollerDigit(screenBuff, i, atoi(thisDigit));
 		
@@ -897,7 +969,7 @@ void animateAlarmDigits(SDL_Surface *screenBuff, char *oldAlarmHHMM, char *newAl
 * Animate a single alarm digit moving from the old value to the new value
 ****************************************************************************/
 
-void animateAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int oldDigitValue, int newDigitValue, int frames) {
+void animateAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int oldDigitValue, int newDigitValue, int frames, SDL_Rect *digitPosRect) {
 	
 	SDL_Rect sourceRect, sourceRect2;
 	SDL_Surface *tempDigit, *tempBuffer;
@@ -953,14 +1025,19 @@ void animateAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int oldD
 				}
 				
 				//And off we go!
-				SDL_FillRect(screenBuff, &currentTheme.alarmDigitPos[digitIndexRef], moodColour);
+				//SDL_FillRect(screenBuff, &currentTheme.alarmDigitPos[digitIndexRef], moodColour);
+				SDL_FillRect(screenBuff, digitPosRect, moodColour);
 				
-				SDL_BlitSurface(elements[ALARMDIGITSCROLLER], &sourceRect, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
+				
+				//SDL_BlitSurface(elements[ALARMDIGITSCROLLER], &sourceRect, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
+				SDL_BlitSurface(elements[ALARMDIGITSCROLLER], &sourceRect, screenBuff, digitPosRect);
 			
 				//Draw the mask
-				SDL_BlitSurface(elements[ALARMDIGITMASK], NULL, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
+				//SDL_BlitSurface(elements[ALARMDIGITMASK], NULL, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
+				SDL_BlitSurface(elements[ALARMDIGITMASK], NULL, screenBuff, digitPosRect);
 				
-				SDL_UpdateRects(screenBuff, 1, &currentTheme.alarmDigitPos[digitIndexRef]);
+				//SDL_UpdateRects(screenBuff, 1, &currentTheme.alarmDigitPos[digitIndexRef]);
+				SDL_UpdateRects(screenBuff, 1, digitPosRect);
 				
 			
 			}
@@ -975,8 +1052,11 @@ void animateAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int oldD
 			printf("animating digit %i %i over %i frames\n", oldDigitValue, newDigitValue, frames);
 		
 			//Start by copying the current digit
-			sourceRect2.x = currentTheme.alarmDigitPos[digitIndexRef].x;
-			sourceRect2.y = currentTheme.alarmDigitPos[digitIndexRef].y;
+			//sourceRect2.x = currentTheme.alarmDigitPos[digitIndexRef].x;
+			//sourceRect2.y = currentTheme.alarmDigitPos[digitIndexRef].y;
+			sourceRect2.x = digitPosRect->x;
+			sourceRect2.y = digitPosRect->y;
+			
 			sourceRect2.w = elements[ALARMDIGITMASK]->w;
 			sourceRect2.h = elements[ALARMDIGITMASK]->h;
 			
@@ -985,7 +1065,9 @@ void animateAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int oldD
 		
 			//Get the RGB to use from teh area directly above this digit
 			
-			colour = getPixel(screenBuff, currentTheme.alarmDigitPos[digitIndexRef].x, currentTheme.alarmDigitPos[digitIndexRef].y -2);
+			//colour = getPixel(screenBuff, currentTheme.alarmDigitPos[digitIndexRef].x, currentTheme.alarmDigitPos[digitIndexRef].y -2);
+			colour = getPixel(screenBuff, digitPosRect->x, digitPosRect->y -2);
+
 			SDL_GetRGBA(colour, screenBuff->format, &red, &green, &blue, &alpha);
 
 			
@@ -1004,12 +1086,15 @@ void animateAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int oldD
 				SDL_FillRect(tempBuffer, NULL, backColour);
 				
 				//Draw mood colour first
-				SDL_FillRect(screenBuff, &currentTheme.alarmDigitPos[digitIndexRef], moodColour);
+				//SDL_FillRect(screenBuff, &currentTheme.alarmDigitPos[digitIndexRef], moodColour);
+				SDL_FillRect(screenBuff, digitPosRect, moodColour);
+
 				
 				SDL_BlitSurface(tempDigit, NULL, screenBuff, &sourceRect2);
 				SDL_BlitSurface(tempBuffer, NULL, screenBuff, &sourceRect2);
 				//Draw the mask
-				SDL_BlitSurface(elements[ALARMDIGITMASK], NULL, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
+				//SDL_BlitSurface(elements[ALARMDIGITMASK], NULL, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
+				SDL_BlitSurface(elements[ALARMDIGITMASK], NULL, screenBuff, digitPosRect);
 				
 				SDL_UpdateRects(screenBuff,1, &sourceRect2);
 				
@@ -1039,16 +1124,19 @@ void animateAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int oldD
 				
 				//And off we go!
 				//Draw mood colour first
-				SDL_FillRect(screenBuff, &currentTheme.alarmDigitPos[digitIndexRef], moodColour);
+				//SDL_FillRect(screenBuff, &currentTheme.alarmDigitPos[digitIndexRef], moodColour);
+				SDL_FillRect(screenBuff, digitPosRect, moodColour);
 				
-				SDL_BlitSurface(elements[ALARMDIGITSCROLLER], &sourceRect, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
+				//SDL_BlitSurface(elements[ALARMDIGITSCROLLER], &sourceRect, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
+				SDL_BlitSurface(elements[ALARMDIGITSCROLLER], &sourceRect, screenBuff, digitPosRect);
 			
 
 				
 				SDL_BlitSurface(tempBuffer, NULL, screenBuff, &sourceRect2);
 				
 				//Draw the mask
-				SDL_BlitSurface(elements[ALARMDIGITMASK], NULL, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
+				//SDL_BlitSurface(elements[ALARMDIGITMASK], NULL, screenBuff, &currentTheme.alarmDigitPos[digitIndexRef]);
+				SDL_BlitSurface(elements[ALARMDIGITMASK], NULL, screenBuff, digitPosRect);
 				
 				SDL_UpdateRects(screenBuff,1, &sourceRect2);
 				
@@ -1645,6 +1733,100 @@ void toggleAlarmStyle() {
 }
 
 
+/****************************************************************************
+*
+* toggleInsomniacModeButton();
+*
+* Function to toggle insomniac mode
+****************************************************************************/
+
+void toggleInsomniacModeButton() {
+	int q;
+	
+	if (isTablet) {
+		setInsomniacMode(-1);
+								
+		if (clockMode == CLOCKMODECLOCKSETTINGS) {
+			//Search for the Insomniac button and redraw it only
+			if (currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelCount > 0) {
+				for (q =0; q < currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelCount; q++) {
+					if (!strcmp(currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelArr[q]->labelKey, "insomniacMode")) {			
+						drawImageLabel(screen, currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelArr[q], CLOCKMODECLOCKSETTINGS, NULL);
+						
+						SDL_UpdateRects(screen, 1, &currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelArr[q]->labelRect);
+						
+						break;
+					}
+				}
+			}
+		}
+	}	
+
+}
+
+
+/****************************************************************************
+*
+* toggleSecondsVisible();
+*
+* Function to toggle whether seconds are shown or not
+****************************************************************************/
+
+void toggleSecondsVisible() {
+	int q;
+	
+	userPreferences.showSeconds = !userPreferences.showSeconds;
+
+								
+	if (clockMode == CLOCKMODECLOCKSETTINGS) {
+		//Search for the Insomniac button and redraw it only
+		if (currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelCount > 0) {
+			for (q =0; q < currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelCount; q++) {
+				if (!strcmp(currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelArr[q]->labelKey, "secondsVisible")) {			
+					drawImageLabel(screen, currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelArr[q], CLOCKMODECLOCKSETTINGS, NULL);
+					
+					SDL_UpdateRects(screen, 1, &currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelArr[q]->labelRect);
+					
+					break;
+				}
+			}
+		}
+	}
+
+
+}
+
+/****************************************************************************
+*
+* toggleInsomniacLock();
+*
+* Function to toggle whether insomniac mode is screen dim locked or not
+****************************************************************************/
+
+void toggleInsomniacLock() {
+	int q;
+	
+	userPreferences.insomniacLocked = !userPreferences.insomniacLocked;
+
+								
+	if (clockMode == CLOCKMODECLOCKSETTINGS) {
+		//Search for the Insomniac button and redraw it only
+		if (currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelCount > 0) {
+			for (q =0; q < currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelCount; q++) {
+				if (!strcmp(currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelArr[q]->labelKey, "insomniacLock")) {			
+					drawImageLabel(screen, currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelArr[q], CLOCKMODECLOCKSETTINGS, NULL);
+					
+					SDL_UpdateRects(screen, 1, &currentTheme.imageLabels[CLOCKMODECLOCKSETTINGS].labelArr[q]->labelRect);
+					
+					break;
+				}
+			}
+		}
+	}
+
+
+}
+
 
 /****************************************************************************
 *
@@ -1680,7 +1862,9 @@ void cycleAlarmMode() {
 * cycleSnoozeTime();
 *
 * Function to cycle the snooze time (5 min increments)
-****************************************************************************/
+
+REDUNDANT AND NOT USED ANYMORE... SLIDER IS BETTER (see below)
+**************************************************************************
 
 void cycleSnoozeTime() {
 	int q;
@@ -1705,6 +1889,21 @@ void cycleSnoozeTime() {
 	}
 
 }
+**/
+
+/****************************************************************************
+*
+* openSnoozeTimeSlider()
+*
+* Function to open the slider interface to choose snooze time
+*
+****************************************************************************/
+
+void openSnoozeTimeSlider() {
+	openSlider("Snooze Time (mins)", &userPreferences.userAlarms[currentAlarmNum]->snoozeTime, 0, 60);
+
+}
+
 
 /****************************************************************************
 *
@@ -1746,8 +1945,11 @@ void pickAlarmSoundFile() {
 	GtkWidget *dialog;
 	GtkFileFilter *filter;
 	guint response;
+	
+	char *filename;
+	
 
-	if (userPreferences.userAlarms[currentAlarmNum]->alertMode == ALARMALERTMODESOUND) {
+	if (userPreferences.userAlarms[currentAlarmNum]->alertMode == ALARMALERTMODESOUND || userPreferences.userAlarms[currentAlarmNum]->alertMode == ALARMALERTMODESOUNDFOLDER) {
 		//Only open it if we're in sound mode
 		
 		//temporarily disable insomniac mode (it'll auto start again once file manager closes)
@@ -1766,22 +1968,52 @@ void pickAlarmSoundFile() {
 		gtk_file_filter_add_pattern (filter, "*.mp3");
 		gtk_file_filter_set_name(filter, "Mp3 Files");
 		
-		char *filename;
+
 		//Use either hildon or general GTK file chooser
 		#if defined(__HILDON_FILE_CHOOSER_DIALOG_H__) 
 			printf("Hildon!\n");
-			dialog = hildon_file_chooser_dialog_new(NULL,
+			if (userPreferences.userAlarms[currentAlarmNum]->alertMode == ALARMALERTMODESOUND) {
+				dialog = hildon_file_chooser_dialog_new(NULL,
 							  GTK_FILE_CHOOSER_ACTION_OPEN
 							  );
+			} else if (userPreferences.userAlarms[currentAlarmNum]->alertMode == ALARMALERTMODESOUNDFOLDER) {
+				dialog = hildon_file_chooser_dialog_new(NULL,
+							  GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER
+							  );
+			}
 		#else
-			dialog = gtk_file_chooser_dialog_new ("Open File",
+			if (userPreferences.userAlarms[currentAlarmNum]->alertMode == ALARMALERTMODESOUND) {
+				dialog = gtk_file_chooser_dialog_new ("Open File",
 							  NULL,
 							  GTK_FILE_CHOOSER_ACTION_OPEN,
 							  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 							  GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 							  NULL);
+			} else if (userPreferences.userAlarms[currentAlarmNum]->alertMode == ALARMALERTMODESOUNDFOLDER) {
+				dialog = gtk_file_chooser_dialog_new ("Open File",
+							  NULL,
+							  GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+							  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+							  GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+							  NULL);
+			}
 		#endif
 		
+		if (userPreferences.userAlarms[currentAlarmNum]->sound != NULL) {
+			gtk_file_chooser_select_filename(GTK_FILE_CHOOSER (dialog), userPreferences.userAlarms[currentAlarmNum]->sound);
+		} else {
+			printf("searching for a path!\n");
+			//Try to find a sound that's not null
+			for (q=0; q< userPreferences.userAlarmsCount; q++) {
+				if (userPreferences.userAlarms[q]->sound != NULL) {
+					printf("found a path! %s\n", userPreferences.userAlarms[q]->sound);
+					gtk_file_chooser_select_filename(GTK_FILE_CHOOSER (dialog), userPreferences.userAlarms[q]->sound);
+					break;
+				}
+			}
+			
+		}
+		
 		//apply filter set
 		gtk_file_chooser_add_filter(GTK_FILE_CHOOSER (dialog), filter);
 		response = gtk_dialog_run(GTK_DIALOG(dialog));
